@@ -7,7 +7,7 @@ import torch.optim as optim
 import os
 from functools import partial
 
-def run(dataset_splited, batch_size, num_nodes, model, objective, optimizer, global_rounds, local_steps, reg_lam, device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')):
+def run(dataset_splited, batch_size, num_nodes, model, objective, optimizer, global_rounds, local_steps, reg, device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')):
     # dt = data_process(dataset)
     # train_splited, test_splited = dt.split_dataset(num_nodes, split['split_para'], split['split_method'])
     train_splited, test_splited, split_para = dataset_splited
@@ -39,7 +39,7 @@ def run(dataset_splited, batch_size, num_nodes, model, objective, optimizer, glo
         print('-------------------Global round %d start-------------------' % (i))
         # single-processing!
         for j in range(num_nodes):
-            nodes[j].local_update_steps(local_steps, partial(nodes[j].train_single_step_fedprox, reg_model = server.model, lam= reg_lam))
+            nodes[j].local_update_steps(local_steps, partial(nodes[j].train_single_step_fedprox, reg_model = server.model, lam= reg))
             nodes[j].local_test()
         # server aggregation
         server.aggregate(nodes, list(range(num_nodes)))
@@ -47,4 +47,4 @@ def run(dataset_splited, batch_size, num_nodes, model, objective, optimizer, glo
         server.acc(nodes, list(range(num_nodes)))
 
     # log
-    log(os.path.basename(__file__)[:-3] + '_' + str(reg_lam) + '_' + split_para , nodes, server)
\ No newline at end of file
+    log(os.path.basename(__file__)[:-3] + '_' + str(reg) + '_' + split_para , nodes, server)
\ No newline at end of file
